// declare globals
    var time_array = [], seismo_data_array = [];

// basic outdoor temp plot options:
var axisMinutes = {
    xaxis: {
    show: true,
    mode: "time",
    timezone: "browser",
    ticks: 6,
    timeformat: "%H:%M"        
    }
};

var axis10seconds = {
    xaxis: {
    show: true,
    mode: null,
    ticks: 6,
    timeformat: "%M"        
    } 
};
var options_seismo={
  series: {
    lines:{show: true},
    shadowSize: 0
  },
  yaxis: {min:null, max: null, tickDecimals: 1 }
};

// set small plot to display hours and detailed plot to display the day & hours
var options_seismo_plot =$.extend({},options_seismo,axisMinutes);

$(document).ready (function()
{

  GetFlotData();

  /* then update time data every 10.1 seconds: */
  setInterval (UpdateFlotData, 10100);

  // use location.replace to prevent browser back button function
  $("#logoff_button").click (function(event)
     {
         location.replace("/logoff");
     });

});
// end of document ready


function GetFlotData()
{
    var xtoobig = 0;

    //update the date header on the page
    var updateTime = moment().format("MMMM Do YYYY");
    $("#timeTitle").text(updateTime);

    var request_post = $.ajax ( {
      "url" : "/plotData.json",
      type : "POST",
      datatype : "json",
      async : true,
      data : {
          // request ten minutes of data:
          plotFrom : moment().subtract('minutes',10).format("YYYY-MM-DD HH:mm:ss"),
          plotTo : moment().format("YYYY-MM-DD HH:mm:ss"),
          } 
    })
    .done ( function (response) {

    for (var i=0; i< response.my_array.length; i++) {
      var data = JSON.parse(response.my_array[i]);
      // seismo_data_array.push([moment(data.time,"YYYY-MM-DD HH:mm:ss"),parseFloat(data.capCount)]);
      seismo_data_array.push([data.time, parseFloat(data.capCount)]);
      if (parseFloat(data.capCount) > 1000.0 || parseFloat(data.capCount) < -1000.0) {
        xtoobig = 1;
      }
    }
    // keep plot range greater than +/- 2000 counts
    if (xtoobig == 0) {
        options_seismo={
            series: {
            lines:{show: true},
            shadowSize: 0
        },
            yaxis: {min:-1000, max: 1000, tickDecimals: 1 }
        };
    } else {
        options_seismo={
            series: {
            lines:{show: true},
            shadowSize: 0
        },
            yaxis: {min:null, max: null, tickDecimals: 1 }
        };
    }
    xtoobig = 0;
    // change the axis if required
    options_seismo_plot = $.extend({},options_seismo,axisMinutes);
    //plot the data
    plotData();

  })
    .fail ( function (textStatus) {
    $("#errorTxt").text("Data Problems").show ("slow"); 
    $("<p>textStatus:"+textStatus+"</p>").appendTo("#errorTxt");
  });
} // end of GetFlotData

function UpdateFlotData()
{
    var xtoobig = 0;
    var lastPoint = seismo_data_array[seismo_data_array.length-1];
    var from_last = lastPoint[0];
    //$("#errorTxt").text("Data Problems").show ("slow"); 
    //$("<p>textStatus:"+lastPoint+"</p>").appendTo("#errorTxt");

    //update the date header on the page
    var updateTime = moment().format("MMMM Do YYYY");
    $("#timeTitle").text(updateTime);

    var request_post = $.ajax ( {
      "url" : "/updateData.json",
      type : "POST",
      datatype : "json",
      async : true,
      data : {
          // request ten minutes of data:
          plotFrom : from_last,
          } 
    })
    .done ( function (response) {

    for (var i=0; i< response.my_array.length; i++) {
      var data = JSON.parse(response.my_array[i]);
      // seismo_data_array.push([moment(data.time,"YYYY-MM-DD HH:mm:ss"),parseFloat(data.capCount)]);
      seismo_data_array.push([data.time, parseFloat(data.capCount)]);
      
    }
    //limit graph to about 1hour of data (decimated by 8) -- 60000/8
    if (seismo_data_array.length > 60000/8) {
        seismo_data_array = seismo_data_array.slice(-60000/8);
      }
    // set the minimum y-range for the plot based upon count data
    for (var i=0; i< seismo_data_array.length; i++) {
        var dataPart = seismo_data_array[i];
        var count = dataPart[1];
        if (count > 1000.0 || count < -1000.0) {
            xtoobig = 1;
          }
    }
    // keep plot range greater than +/- 2000 counts
    if (xtoobig == 0) {
        options_seismo={
            series: {
            lines:{show: true},
            shadowSize: 0
        },
            yaxis: {min:-1000, max: 1000, tickDecimals: 1 }
        };
    } else {
        options_seismo={
            series: {
            lines:{show: true},
            shadowSize: 0
        },
            yaxis: {min:null, max: null, tickDecimals: 1 }
        };
    }
    xtoobig = 0;
    // change the axis if required
    options_seismo_plot = $.extend({},options_seismo,axisMinutes);
    //plot the data
    plotData();

  })
    .fail ( function (textStatus) {
    $("#errorTxt").text("Data Problems").show ("slow"); 
    $("<p>textStatus:"+textStatus+"</p>").appendTo("#errorTxt");
  });
} // end of UpdateFlotData

function plotData() {
    $.plot($("#seismoPlot"),[{label:"Cap2Dig Counts",data:seismo_data_array}],options_seismo_plot);
    // seismo_data_array = [];
}
